unit CELIKAPI_Savkic;

interface

uses
  Windows;

const
  EID_MAX_DocRegNo = 9;
  EID_MAX_IssuingDate = 10;
  EID_MAX_ExpiryDate = 10;
  EID_MAX_IssuingAuthority = 30;

  EID_MAX_PersonalNumber = 13;
  EID_MAX_Surname = 60;
  EID_MAX_GivenName = 40;
  EID_MAX_ParentGivenName = 25;
  EID_MAX_Sex = 2;
  EID_MAX_PlaceOfBirth = 25;
  EID_MAX_StateOfBirth = 25;
  EID_MAX_DateOfBirth = 10;
  EID_MAX_CommunityOfBirth = 25;

  EID_MAX_State = 3;
  EID_MAX_Community = 25;
  EID_MAX_Place = 25;
  EID_MAX_Street = 36;
  EID_MAX_HouseNumber = 5;
  EID_MAX_HouseLetter = 2;
  EID_MAX_Entrance = 3;
  EID_MAX_Floor = 3;
  EID_MAX_ApartmentNumber = 6;

  EID_MAX_Portrait = 7700;

  EID_OK = 0;
  EID_E_GENERAL_ERROR = -1;
  EID_E_INVALID_PARAMETER = -2;
  EID_E_VERSION_NOT_SUPPORTED = -3;
  EID_E_NOT_INITIALIZED = -4;
  EID_E_UNABLE_TO_EXECUTE = -5;
  EID_E_READER_ERROR = -6;
  EID_E_CARD_MISSING = -7;
  EID_E_CARD_UNKNOWN = -8;
  EID_E_CARD_MISMATCH = -9;
  EID_E_UNABLE_TO_OPEN_SESSION = -10;
  EID_E_DATA_MISSING = -11;
  EID_E_CARD_SECFORMAT_CHECK_ERROR = -12;
  EID_E_SECFORMAT_CHECK_CERT_ERROR = -13;

type
  tagEID_DOCUMENT_DATA = record
    docRegNo: array[0..EID_MAX_DocRegNo - 1] of Char;
    docRegNoSize: Integer;
    issuingDate: array[0..EID_MAX_IssuingDate - 1] of Char;
    issuingDateSize: Integer;
    expiryDate: array[0..EID_MAX_ExpiryDate - 1] of Char;
    expiryDateSize: Integer;
    issuingAuthority: array[0..EID_MAX_IssuingAuthority - 1] of Char;
    issuingAuthoritySize: Integer;
  end {tagEID_DOCUMENT_DATA};

 EID_DOCUMENT_DATA = tagEID_DOCUMENT_DATA;
 PEID_DOCUMENT_DATA = ^ tagEID_DOCUMENT_DATA;

type
  tagEID_FIXED_PERSONAL_DATA = record
    personalNumber: array[0..EID_MAX_PersonalNumber - 1] of Integer;
    personalNumberSize: Integer;
    surname: array[0..EID_MAX_Surname - 1] of Char;
    surnameSize: Integer;
    givenName: array[0..EID_MAX_GivenName - 1] of Char;
    givenNameSize: Integer;
    parentGivenName: array[0..EID_MAX_ParentGivenName - 1] of Char;
    parentGivenNameSize: Integer;
    sex: array[0..EID_MAX_Sex - 1] of Char;
    sexSize: Integer;
    placeOfBirth: array[0..EID_MAX_PlaceOfBirth - 1] of Char;
    placeOfBirthSize: Integer;
    stateOfBirth: array[0..EID_MAX_StateOfBirth - 1] of Char;
    stateOfBirthSize: Integer;
    dateOfBirth: array[0..EID_MAX_DateOfBirth - 1] of Char;
    dateOfBirthSize: Integer;
    communityOfBirth: array[0..EID_MAX_CommunityOfBirth - 1] of Char;
    communityOfBirthSize: Integer;
  end {tagEID_FIXED_PERSONAL_DATA};

 EID_FIXED_PERSONAL_DATA = tagEID_FIXED_PERSONAL_DATA;
 PEID_FIXED_PERSONAL_DATA = ^tagEID_FIXED_PERSONAL_DATA;

type
  tagEID_VARIABLE_PERSONAL_DATA = record
    state: array[0..EID_MAX_State - 1] of Char;
    stateSize: Integer;
    community: array[0..EID_MAX_Community - 1] of Char;
    communitySize: Integer;
    place: array[0..EID_MAX_Place - 1] of Char;
    placeSize: Integer;
    street: array[0..EID_MAX_Street - 1] of Char;
    streetSize: Integer;
    houseNumber: array[0..EID_MAX_HouseNumber - 1] of Char;
    houseNumberSize: Integer;
    houseLetter: array[0..EID_MAX_HouseLetter - 1] of Char;
    houseLetterSize: Integer;
    entrance: array[0..EID_MAX_Entrance - 1] of Char;
    entranceSize: Integer;
    floor: array[0..EID_MAX_Floor - 1] of Char;
    floorSize: Integer;
    apartmentNumber: array[0..EID_MAX_ApartmentNumber - 1] of Char;
    apartmentNumberSize: Integer;
  end {tagEID_VARIABLE_PERSONAL_DATA};

  EID_VARIABLE_PERSONAL_DATA = tagEID_VARIABLE_PERSONAL_DATA;
  PEID_VARIABLE_PERSONAL_DATA = ^tagEID_VARIABLE_PERSONAL_DATA;

type
  tagEID_PORTRAIT = record
    portrait: array[0..EID_MAX_Portrait - 1] of BYTE;
    portraitSize: Integer;
  end {tagEID_PORTRAIT};

  EID_PORTRAIT = tagEID_PORTRAIT;
  PEID_PORTRAIT = ^tagEID_PORTRAIT;

var
  EidStartup: function(nApiVersion: Integer): Integer; stdcall;
  EidCleanup: function: Integer; stdcall;

  EidBeginRead: function(szReader: LPCSTR): Integer; stdcall;
  EidEndRead: function: Integer; stdcall;

  EidReadDocumentData: function(pData: PEID_DOCUMENT_DATA): Integer; stdcall;
  EidReadFixedPersonalData: function(pData: PEID_FIXED_PERSONAL_DATA): Integer; stdcall;
  EidReadVariablePersonalData: function(pData: PEID_VARIABLE_PERSONAL_DATA): Integer; stdcall;
  EidReadPortrait: function(pData: PEID_PORTRAIT): Integer; stdcall;

implementation

var
  DLLHandle: HMODULE;

procedure LoadDLL;
begin
  DLLHandle := LoadLibrary('CelikApi.dll');

  if DLLHandle <> 0 then
  begin
    @EidStartup := GetProcAddress(DLLHandle, 'EidStartup');
    @EidCleanup := GetProcAddress(DLLHandle, 'EidCleanup');
    @EidBeginRead := GetProcAddress(DLLHandle, 'EidBeginRead');
    @EidEndRead := GetProcAddress(DLLHandle, 'EidEndRead');
    @EidReadDocumentData := GetProcAddress(DLLHandle, 'EidReadDocumentData');
    @EidReadFixedPersonalData := GetProcAddress(DLLHandle, 'EidReadFixedPersonalData');
    @EidReadVariablePersonalData := GetProcAddress(DLLHandle, 'EidReadVariablePersonalData');
    @EidReadPortrait := GetProcAddress(DLLHandle, 'EidReadPortrait');
  end;
end;

initialization
  LoadDLL;

finalization
  if DLLHandle <> 0 then
    FreeLibrary(DLLHandle)

end.
